#
# spec file for package python-flake8-bugbear
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-flake8-bugbear
Version:        24.2.6
Release:        2.1
Summary:        A plugin for flake8 finding likely bugs and design problems in your program
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/PyCQA/flake8-bugbear
Source:         https://files.pythonhosted.org/packages/source/f/flake8-bugbear/flake8-bugbear-%{version}.tar.gz
BuildRequires:  %{python_module attrs >= 19.2.0}
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module flake8 >= 6.0.0}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module hypothesmith}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-attrs >= 19.2.0
Requires:       python-flake8 >= 6.0.0
BuildArch:      noarch
%python_subpackages

%description
A plugin for Flake8 finding likely bugs and design problems in your
program.  Contains warnings that don't belong in pyflakes and
pycodestyle.

%prep
%setup -q -n flake8-bugbear-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# Fuzz testing needs fast machine for quick enough data responses
%pytest -k 'not TestFuzz'

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/bugbear.py
%{python_sitelib}/flake8[-_]bugbear-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__/bugbear*

%changelog
* Tue May 27 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Mon Mar 25 2024 Dirk Müller <dmueller@suse.com>
- update to 24.2.6:
  * B902: Remove decorators named validator and root_validator
    from B902 checks
  * B038: Change B038 to B909 and make it optional
* Sat Jan 20 2024 Dirk Müller <dmueller@suse.com>
- update to 24.1.17:
  * B038: Restrict rule to mutation functions only
- update to 24.1.16:
  * B036: Fix crash on ``raise`` statements raising something
    other than
- update to 24.1.15:
  * B038: Add check for mutations of loop iterator
  * B037: Add check for yielding or returning values in
    __init__()
  * B017: make B017 also apply to BaseException
  * B036: Add check for except BaseException without re-raising
* Mon Dec  4 2023 Dirk Müller <dmueller@suse.com>
- update to 23.12.2:
  * B018: to detect useless-statements at all levels (#434)
  * B018: Add classname to b018 useless-expression output (#433)
  * B018: Include tuples in b018 useless-statement check (#432)
- update to 23.11.28:
  * B035: Fix false positive when named expressions are used
    (#430)
- update to 23.11.26:
  * B035: add check for static keys in dict-comprehension (#426)
  * B902: Add exceptions for standard library metaclasses (#415)
  * B017: Modify to no longer have a false negative when raises()
    is imported directly from pytest (#424)
  * B026: Fix bug where the check was not triggered for calls
    where the caller is an attribute (#420)
* Mon Sep 18 2023 Daniel Garcia <daniel.garcia@suse.com>
- update to 23.9.16:
  * add --classmethod-decorators (#405)
  * fix name collision for node_stack on python 3.12 (#406)
  * Use pypa/build to build the package (#404)
* Tue Jul 11 2023 Dirk Müller <dmueller@suse.com>
- update to 23.7.10:
  * Add B034: re.sub/subn/split must pass flags/count/maxsplit as
    keyword arguments.
  * Fix a crash and several test failures on Python 3.12, all
    relating to the B907 * check.
  * Declare support for Python 3.12.
* Sun Jun 11 2023 Dirk Müller <dmueller@suse.com>
- update to 23.6.5:
  * Include tox.ini in MANIFEST.in for sdist.
  * Improve B033 (duplicate set items)
* Thu May 18 2023 Dirk Müller <dmueller@suse.com>
- update to 23.5.9:
  * Add B033: Detect duplicate items in sets
  * Add B908: Detect assertRauses like contexts only has top
    level statements that could throw
  * Add B028: Allow stacklevel to be explicitly assigned as a
    positional argument
  * Remove more < 3.8 checks / assertions
* Fri Apr 28 2023 Dirk Müller <dmueller@suse.com>
- update to 23.3.23:
  * flake8-bugbear is now >= 3.8.1 project like flake8>=6.0.0
  * This has allowed some more modern AST usage cleanup and less
    CI running etc.
  * B030: Fix crash on certain unusual except handlers (e.g.
    ``except a[0].b:``)
  * B950: now ignores 'noqa' and 'type: ignore' comments.
  * B005: Do not flag when using the ``strip()`` method on an
    imported module.
  * B030: Allow calls and starred expressions in except handlers.
* Wed Feb 15 2023 Dirk Müller <dmueller@suse.com>
- update to 23.2.13:
  * B906: Add visit_Bytes, visit_Num and visit_Str to
    the list of visit_* functions that are ignored by the B906
    check.
  * B016: Warn when raising f-strings.
  * Add B028: Check for an explicit stacklevel keyword argument
    on the warn method from the warnings module.
  * Add B029: Check when trying to use ``except`` with an empty
    tuple i.e. ``except: ()``.
  * Add B032: Check for possible unintentional type annotations
    instead of assignments.
  * B024: now ignores classes without any methods. (#336)
  * B017: Don't warn when ``pytest.raises()`` has a ``match``
    argument. (#334)
  * B906: Ignore ``visit_`` functions with a ``_fields``
    attribute that can't contain ast.AST subnodes. (#330)
  * Rename B028 to B907, making it optional/opinionated.
  * Add B906: ``visit_`` function with no further calls to a
    ``visit`` function. (#313)
  * Add B028: Suggest ``!r`` when formatted value in f-string is
    surrounded by quotes. (#319)
* Thu Dec 15 2022 Dirk Müller <dmueller@suse.com>
- update to 22.12.6 (bsc#1206225):
  * Add B905: `zip()` without an explicit `strict=` parameter. (#314)
  * B027: ignore @overload when typing is imported with other names (#309)
* Thu Oct 27 2022 Martin Liška <mliska@suse.cz>
- Update to 22.10.27:
  * B027: Ignore @overload decorator (#306)
  * B023: Also fix map (#305)
  * B023: Avoid false alarms with filter, reduce, key= and return. Added tests for functools (#303)
* Wed Oct 26 2022 Martin Liška <mliska@suse.cz>
- Update to 22.10.25:
  * Make B015 and B018 messages slightly more polite (#298)
  * Add B027: Empty method in abstract base class with no abstract decorator
  * Multiple B024 false positive fixes
  * Move CI to use tox (#294)
  * Move to using PEP621 / pyproject.toml package (#291)
  * Tested in 3.11
* Fri Aug 26 2022 Martin Liška <mliska@suse.cz>
- Update 22.8.23:
  * Add B024 error code to message for B024 (#276)
  * Add B024: abstract base class with no abstract methods (#273)
  * Implement late-binding loop check (#265)
  * late-binding closures are a classic gotcha.
  * Don't crash when select / extend_select are None (#261)
  * Ignore lambda arguments for B020 (#259)
  * Fix missing space typos in B021, B022 error messages (#257)
  * Ignore black formatting for b013 test case (#251)
  * B010 Fix lambda flase positive (#246)
  * B008 Fix edge case with lambda functions (#243)
  * B006 and B008: Detect function calls at any level of the default expression (#239)
  * B020: Fix comprehension false postives (#238)
  * Tweak B019 desc (#237)
  * B022: No arguments passed to contextlib.suppress (#231)
  * B021: f-string used as docstring. (#230)
  * B020: ensure loop control variable doesn't overrides iterable it iterates (#220)
  * B019: check to find cache decorators on class methods (#218)
  * Fix crash on long empty string (#223)
  * B018: Ignore JoinedStr (#216)
  * Build universal Python 3 wheels (#214)
  * B950: Add same special cases as E501 (#213)
  * B018: Disable strings from check for now (#209)
  * B904: ensure the raise is in the same context with the except (#191)
  * Add Option to extend the list of immutable calls (#204)
  * Update B014: binascii.Error is now treated as a subclass of ValueError (#206)
  * add simple pre-commit config (#205)
  * Test with 3.10 official
  * Add B018 check to find useless declarations (#196, #202)
  * Fix crash on call in except statement in _to_name_str (#187)
  * Update B006: list, dictionary, and set comprehensions are now also disallowed (#186)
  * Update B008: Whitelist more immutable function calls (#173)
  * Remove Python Compatibility Warnings (#182)
  * Add B904: check for raise without from in an except clause (#181)
  * Add Python 3.10 tests to ensure we pass (#183)
  * Verify the element in item_context.args is of type ast.Name for b017
  * Add another hasattr() check to b017 visit for .func
  * Add B017: check for gotta-catch-em-all assertRaises(Exception)
  * Fix crash on tuple expansion in try/except block (#161)
  * Fix grammar in B015 (#150)
  * Make sure float infinity/NaN does not trigger B008 (#155)
  * Handle positional-only args in class methods (#158)
  * Support exception aliases properly in B014 (#129)
  * Add B015: Pointless comparison (#130)
  * Remove check for # noqa comments (#134)
  * Ignore exception classes which are not types (#135)
  * Introduce B016 to check for raising a literal. (#141)
  * Exclude types.MappingProxyType() from B008. (#144)
* Thu Apr 16 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 20.1.4:
  * Ignore keywords for B009/B010
  * Silence B009/B010 for non-identifiers
  * State an ignore might be needed for optional B9x checks
  * Fix error on attributes-of-attributes in except (...): clauses
  * Allow continue/break within loops in finally clauses for B012
  * For B001, also check for except ():
  * Introduce B013 and B014 to check tuples in except (..., ): statements
  * Warn about continue/return/break in finally block (#100)
  * Removed a colon from the descriptive message in B008. (#96)
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 19.8.0:
  * Fix .travis.yml syntax + add Python 3.8 + nightly tests
  * Fix black formatting + enforce via CI
  * Make B901 not apply to __await__ methods
* Mon Apr  1 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 19.3.0:
  * allow 'mcs' for metaclass classmethod first arg (PyCharm default)
  * Introduce B011
  * Introduce B009 and B010
  * Exclude immutable calls like tuple() and frozenset() from B008
  * For B902, the first argument for metaclass class methods can be "mcs", matching the name preferred by PyCharm.
* Fri Nov  2 2018 Matej Cepl <mcepl@suse.com>
- Update to 18.8.0:
  * Exclude immutable calls like tuple() and frozenset() from B008
  * Examine kw-only args for mutable defaults
  * Black all the .py files - Like one should (#48)
  * Add testing and document support for the Python 3.7 release
  * Avoid adding the visitor as an __init__ parameter (Fixes #39)
    (#40)
  * Add trove classifier 'Programming Language :: Python :: 3 :: Only'
  * Fix pathlib link in readme (#36)
* Wed Jul 18 2018 tchvatal@suse.com
- This module requires py3.5+ thus restrict the build
* Tue Jul 10 2018 dmueller@suse.com
- Initial package (18.2)
